@@ -4,6 +4,7 @@
 from __future__ import annotations
 
 import heapq
+from contextlib import suppress
 from math import isnan
 from typing import (
     Any,
@@ -18,15 +19,14 @@ from typing import (
 
 from rapidfuzz._utils import ScorerFlag
 from rapidfuzz.fuzz import WRatio, ratio
-from rapidfuzz.utils import default_process
 
 __all__ = ["extract", "extract_iter", "extractOne", "cdist"]
 
 
-def _get_scorer_flags_py(scorer: Any, kwargs: dict[str, Any]) -> tuple[int, int]:
+def _get_scorer_flags_py(scorer: Any, scorer_kwargs: dict[str, Any]) -> tuple[int, int]:
     params = getattr(scorer, "_RF_ScorerPy", None)
     if params is not None:
-        flags = params["get_scorer_flags"](**kwargs)
+        flags = params["get_scorer_flags"](**scorer_kwargs)
         return (flags["worst_score"], flags["optimal_score"])
     return (0, 100)
 
@@ -47,10 +47,10 @@ def extract_iter(
     choices: Iterable[Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> Iterable[tuple[Sequence[Hashable], int | float, int]]:
     ...
 
@@ -61,24 +61,23 @@ def extract_iter(
     choices: Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> Iterable[tuple[Sequence[Hashable], int | float, Any]]:
     ...
 
 
 def extract_iter(
     query: Sequence[Hashable] | None,
-    choices: Iterable[Sequence[Hashable] | None]
-    | Mapping[Any, Sequence[Hashable] | None],
+    choices: Iterable[Sequence[Hashable] | None] | Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = default_process,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> Iterable[tuple[Sequence[Hashable], int | float, Any]]:
     """
     Find the best match in a list of choices
@@ -97,8 +96,8 @@ def extract_iter(
         a custom function, which returns a normalized edit distance.
         fuzz.WRatio is used by default.
     processor : Callable, optional
-        Optional callable that reformats the strings.
-        utils.default_process is used by default, which lowercases the strings and trims whitespace
+        Optional callable that is used to preprocess the strings before
+        comparing them. Default is None, which deactivates this behaviour.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
         edit distance and matches with a `distance <= score_cutoff` are ignored. When a
@@ -108,9 +107,9 @@ def extract_iter(
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Yields
     -------
@@ -124,10 +123,10 @@ def extract_iter(
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
             In this case only choices which have a `distance <= max` are yielded.
-            An example of a scorer with this behavior is `string_metric.levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are yielded.
-            An example of a scorer with this behavior is `string_metric.normalized_levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.normalized_similarity`.
 
           Note, that for all scorers, which are not provided by RapidFuzz, only normalized edit distances are supported.
 
@@ -137,17 +136,14 @@ def extract_iter(
           * The `key of choice` when choices is a mapping like a dict, or a pandas Series
 
     """
-    worst_score, optimal_score = _get_scorer_flags_py(scorer, kwargs)
+    _ = score_hint
+    scorer_kwargs = scorer_kwargs or {}
+    worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
     if _is_none(query):
         return
 
-    if processor is True:
-        processor = default_process
-    elif processor is False:
-        processor = None
-
     if score_cutoff is None:
         score_cutoff = worst_score
 
@@ -162,16 +158,13 @@ def extract_iter(
             continue
 
         if processor is None:
-            score = scorer(
-                query, choice, processor=None, score_cutoff=score_cutoff, **kwargs
-            )
+            score = scorer(query, choice, score_cutoff=score_cutoff, **scorer_kwargs)
         else:
             score = scorer(
                 query,
                 processor(choice),
-                processor=None,
                 score_cutoff=score_cutoff,
-                **kwargs,
+                **scorer_kwargs,
             )
 
         if lowest_score_worst:
@@ -188,10 +181,10 @@ def extractOne(
     choices: Iterable[Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> tuple[Sequence[Hashable], int | float, int] | None:
     ...
 
@@ -202,24 +195,23 @@ def extractOne(
     choices: Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> tuple[Sequence[Hashable], int | float, Any] | None:
     ...
 
 
 def extractOne(
     query: Sequence[Hashable] | None,
-    choices: Iterable[Sequence[Hashable] | None]
-    | Mapping[Any, Sequence[Hashable] | None],
+    choices: Iterable[Sequence[Hashable] | None] | Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = default_process,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> tuple[Sequence[Hashable], int | float, Any] | None:
     """
     Find the best match in a list of choices. When multiple elements have the same similarity,
@@ -239,8 +231,8 @@ def extractOne(
         a custom function, which returns a normalized edit distance.
         fuzz.WRatio is used by default.
     processor : Callable, optional
-        Optional callable that reformats the strings.
-        utils.default_process is used by default, which lowercases the strings and trims whitespace
+        Optional callable that is used to preprocess the strings before
+        comparing them. Default is None, which deactivates this behaviour.
     score_cutoff : Any, optional
         Optional argument for a score threshold. When an edit distance is used this represents the maximum
         edit distance and matches with a `distance <= score_cutoff` are ignored. When a
@@ -250,9 +242,9 @@ def extractOne(
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Returns
     -------
@@ -266,10 +258,10 @@ def extractOne(
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
             In this case only choices which have a `distance <= score_cutoff` are returned.
-            An example of a scorer with this behavior is `string_metric.levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are returned.
-            An example of a scorer with this behavior is `string_metric.normalized_levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.normalized_similarity`.
 
           Note, that for all scorers, which are not provided by RapidFuzz, only normalized edit distances are supported.
 
@@ -285,24 +277,24 @@ def extractOne(
     --------
 
     >>> from rapidfuzz.process import extractOne
-    >>> from rapidfuzz.string_metric import levenshtein, normalized_levenshtein
+    >>> from rapidfuzz.distance import Levenshtein
     >>> from rapidfuzz.fuzz import ratio
 
     extractOne can be used with normalized edit distances.
 
     >>> extractOne("abcd", ["abce"], scorer=ratio)
     ("abcd", 75.0, 1)
-    >>> extractOne("abcd", ["abce"], scorer=normalized_levenshtein)
-    ("abcd", 75.0, 1)
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.normalized_similarity)
+    ("abcd", 0.75, 1)
 
     extractOne can be used with edit distances as well.
 
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein)
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance)
     ("abce", 1, 0)
 
-    additional settings of the scorer can be passed as keyword arguments to extractOne
+    additional settings of the scorer can be passed via the scorer_kwargs argument to extractOne
 
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein, weights=(1,1,2))
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance, scorer_kwargs={"weights":(1,1,2)})
     ("abcde", 2, 1)
 
     when a mapping is used for the choices the key of the choice is returned instead of the List index
@@ -310,16 +302,12 @@ def extractOne(
     >>> extractOne("abcd", {"key": "abce"}, scorer=ratio)
     ("abcd", 75.0, "key")
 
-    By default each string is preprocessed using `utils.default_process`, which lowercases the strings,
-    replaces non alphanumeric characters with whitespaces and trims whitespaces from start and end of them.
-    This behavior can be changed by passing a custom function, or None to disable the behavior. Preprocessing
-    can take a significant part of the runtime, so it makes sense to disable it, when it is not required.
-
+    It is possible to specify a processor function which is used to preprocess the strings before comparing them.
 
     >>> extractOne("abcd", ["abdD"], scorer=ratio)
-    ("abcD", 100.0, 0)
-    >>> extractOne("abcd", ["abdD"], scorer=ratio, processor=None)
     ("abcD", 75.0, 0)
+    >>> extractOne("abcd", ["abdD"], scorer=ratio, processor=utils.default_process)
+    ("abcD", 100.0, 0)
     >>> extractOne("abcd", ["abdD"], scorer=ratio, processor=lambda s: s.upper())
     ("abcD", 100.0, 0)
 
@@ -335,23 +323,20 @@ def extractOne(
 
     For edit distances all results with an edit distance above the score_cutoff are filtered out
 
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein, weights=(1,1,2))
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance, scorer_kwargs={"weights":(1,1,2)})
     ("abce", 2, 0)
-    >>> extractOne("abcd", ["abce"], scorer=levenshtein, weights=(1,1,2), score_cutoff=1)
+    >>> extractOne("abcd", ["abce"], scorer=Levenshtein.distance, scorer_kwargs={"weights":(1,1,2)}, score_cutoff=1)
     None
 
     """
-    worst_score, optimal_score = _get_scorer_flags_py(scorer, kwargs)
+    _ = score_hint
+    scorer_kwargs = scorer_kwargs or {}
+    worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
     if _is_none(query):
         return None
 
-    if processor is True:
-        processor = default_process
-    elif processor is False:
-        processor = None
-
     if score_cutoff is None:
         score_cutoff = worst_score
 
@@ -368,16 +353,13 @@ def extractOne(
             continue
 
         if processor is None:
-            score = scorer(
-                query, choice, processor=None, score_cutoff=score_cutoff, **kwargs
-            )
+            score = scorer(query, choice, score_cutoff=score_cutoff, **scorer_kwargs)
         else:
             score = scorer(
                 query,
                 processor(choice),
-                processor=None,
                 score_cutoff=score_cutoff,
-                **kwargs,
+                **scorer_kwargs,
             )
 
         if lowest_score_worst:
@@ -401,11 +383,11 @@ def extract(
     choices: Collection[Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     limit: int | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> list[tuple[Sequence[Hashable], int | float, int]]:
     ...
 
@@ -416,26 +398,25 @@ def extract(
     choices: Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = None,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     limit: int | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> list[tuple[Sequence[Hashable], int | float, Any]]:
     ...
 
 
 def extract(
     query: Sequence[Hashable] | None,
-    choices: Collection[Sequence[Hashable] | None]
-    | Mapping[Any, Sequence[Hashable] | None],
+    choices: Collection[Sequence[Hashable] | None] | Mapping[Any, Sequence[Hashable] | None],
     *,
     scorer: Callable[..., int | float] = WRatio,
-    processor: Callable[..., Sequence[Hashable]] | None | bool = default_process,
+    processor: Callable[..., Sequence[Hashable]] | None = None,
     limit: int | None = 5,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> list[tuple[Sequence[Hashable], int | float, Any]]:
     """
     Find the best matches in a list of choices. The list is sorted by the similarity.
@@ -455,8 +436,8 @@ def extract(
         a custom function, which returns a normalized edit distance.
         fuzz.WRatio is used by default.
     processor : Callable, optional
-        Optional callable that reformats the strings.
-        utils.default_process is used by default, which lowercases the strings and trims whitespace
+        Optional callable that is used to preprocess the strings before
+        comparing them. Default is None, which deactivates this behaviour.
     limit : int
         maximum amount of results to return
     score_cutoff : Any, optional
@@ -468,9 +449,9 @@ def extract(
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Returns
     -------
@@ -484,10 +465,10 @@ def extract(
 
           * An edit distance (distance is 0 for a perfect match and > 0 for non perfect matches).
             In this case only choices which have a `distance <= max` are returned.
-            An example of a scorer with this behavior is `string_metric.levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.distance`.
           * A normalized edit distance (similarity is a score between 0 and 100, with 100 being a perfect match).
             In this case only choices which have a `similarity >= score_cutoff` are returned.
-            An example of a scorer with this behavior is `string_metric.normalized_levenshtein`.
+            An example of a scorer with this behavior is `Levenshtein.normalized_similarity`.
 
           Note, that for all scorers, which are not provided by RapidFuzz, only normalized edit distances are supported.
 
@@ -500,7 +481,8 @@ def extract(
         has the `highest similarity`/`smallest distance`.
 
     """
-    worst_score, optimal_score = _get_scorer_flags_py(scorer, kwargs)
+    scorer_kwargs = scorer_kwargs or {}
+    worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
     result_iter = extract_iter(
@@ -509,7 +491,8 @@ def extract(
         processor=processor,
         scorer=scorer,
         score_cutoff=score_cutoff,
-        **kwargs,
+        score_hint=score_hint,
+        scorer_kwargs=scorer_kwargs,
     )
 
     if limit is None:
@@ -520,16 +503,14 @@ def extract(
     return heapq.nsmallest(limit, result_iter, key=lambda i: i[1])
 
 
-try:
+with suppress(BaseException):
     import numpy as np
-except BaseException:
-    pass
 
 
 def _dtype_to_type_num(
     dtype: np.dtype | None,
     scorer: Callable[..., int | float],
-    **kwargs: dict[str, Any],
+    scorer_kwargs: dict[str, Any],
 ) -> np.dtype:
     import numpy as np
 
@@ -538,7 +519,7 @@ def _dtype_to_type_num(
 
     params = getattr(scorer, "_RF_ScorerPy", None)
     if params is not None:
-        flags = params["get_scorer_flags"](**kwargs)
+        flags = params["get_scorer_flags"](**scorer_kwargs)
         if flags["flags"] & ScorerFlag.RESULT_I64:
             return np.int32
         return np.float32
@@ -546,10 +527,10 @@ def _dtype_to_type_num(
     return np.float32
 
 
-def _is_symmetric(scorer: Callable[..., int | float], **kwargs: dict[str, Any]) -> bool:
+def _is_symmetric(scorer: Callable[..., int | float], scorer_kwargs: dict[str, Any]) -> bool:
     params = getattr(scorer, "_RF_ScorerPy", None)
     if params is not None:
-        flags = params["get_scorer_flags"](**kwargs)
+        flags = params["get_scorer_flags"](**scorer_kwargs)
         if flags["flags"] & ScorerFlag.SYMMETRIC:
             return True
 
@@ -566,7 +547,7 @@ def cdist(
     score_hint: int | float | None = None,
     dtype: np.dtype | None = None,
     workers: int = 1,
-    **kwargs: Any,
+    scorer_kwargs: dict[str, Any] | None = None,
 ) -> np.ndarray:
     """
     Compute distance/similarity between each pair of the two collections of inputs.
@@ -613,9 +594,9 @@ def cdist(
         Supply -1 to use all available CPU cores.
         This argument is only available for scorers using the RapidFuzz C-API so far, since it
         releases the Python GIL.
-    **kwargs : Any, optional
+    scorer_kwargs : dict[str, Any], optional
         any other named parameters are passed to the scorer. This can be used to pass
-        e.g. weights to string_metric.levenshtein
+        e.g. weights to `Levenshtein.distance`
 
     Returns
     -------
@@ -625,42 +606,35 @@ def cdist(
     """
     import numpy as np
 
-    dtype = _dtype_to_type_num(dtype, scorer, **kwargs)
+    _ = workers, score_hint
+    scorer_kwargs = scorer_kwargs or {}
+    dtype = _dtype_to_type_num(dtype, scorer, scorer_kwargs)
     results = np.zeros((len(queries), len(choices)), dtype=dtype)
 
-    if queries is choices and _is_symmetric(scorer, **kwargs):
-        if processor is None:
-            proc_queries = list(queries)
-        else:
-            proc_queries = [processor(x) for x in queries]
+    if processor is None:
+        proc_choices = list(choices)
+    else:
+        proc_choices = [x if _is_none(x) else processor(x) for x in choices]
 
-        for i, query in enumerate(proc_queries):
-            results[i, i] = scorer(
-                query, query, processor=None, score_cutoff=score_cutoff, **kwargs
-            )
-            for j in range(i + 1, len(proc_queries)):
+    if queries is choices and _is_symmetric(scorer, scorer_kwargs):
+        for i, query in enumerate(proc_choices):
+            results[i, i] = scorer(query, query, score_cutoff=score_cutoff, **scorer_kwargs)
+            for j in range(i + 1, len(proc_choices)):
                 results[i, j] = results[j, i] = scorer(
                     query,
-                    proc_queries[j],
-                    processor=None,
+                    proc_choices[j],
                     score_cutoff=score_cutoff,
-                    **kwargs,
+                    **scorer_kwargs,
                 )
     else:
-        if processor is None:
-            proc_choices = list(choices)
-        else:
-            proc_choices = [processor(x) for x in choices]
-
         for i, query in enumerate(queries):
-            proc_query = processor(query) if processor else query
+            proc_query = processor(query) if (processor and not _is_none(query)) else query
             for j, choice in enumerate(proc_choices):
                 results[i, j] = scorer(
                     proc_query,
                     choice,
-                    processor=None,
                     score_cutoff=score_cutoff,
-                    **kwargs,
+                    **scorer_kwargs,
                 )
 
     return results
