@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import random
 from itertools import product
 from string import ascii_letters, digits, punctuation
@@ -8,7 +10,7 @@ import pytest
 from hypothesis import assume, given, settings
 
 from rapidfuzz import fuzz, process, utils
-from rapidfuzz.distance import Indel_cpp, Levenshtein_cpp, Levenshtein_py
+from rapidfuzz.distance import Levenshtein_py, metrics_cpp
 from tests.distance.common import Indel, JaroWinkler, Levenshtein
 
 
@@ -38,10 +40,7 @@ def levenshtein(s1, s2, weights=(1, 1, 1)):
 
     for col in range(1, cols):
         for row in range(1, rows):
-            if s1[row - 1] == s2[col - 1]:
-                cost = 0
-            else:
-                cost = substitute
+            cost = 0 if s1[row - 1] == s2[col - 1] else substitute
 
             dist[row][col] = min(
                 dist[row - 1][col] + delete,  # deletion
@@ -77,6 +76,9 @@ def normalize_distance(dist, s1, s2, weights=(1, 1, 1)):
 
 
 def jaro_similarity(pattern, text):
+    if not pattern and not text:
+        return 1.0
+
     P_flag = [0] * (len(pattern) + 1)
     T_flag = [0] * (len(text) + 1)
 
@@ -114,11 +116,7 @@ def jaro_similarity(pattern, text):
 
     Transpositions = Transpositions // 2
 
-    sim = (
-        CommonChars / len(pattern)
-        + CommonChars / len(text)
-        + (CommonChars - Transpositions) / CommonChars
-    )
+    sim = CommonChars / len(pattern) + CommonChars / len(text) + (CommonChars - Transpositions) / CommonChars
     return sim / 3
 
 
@@ -148,9 +146,7 @@ def partial_ratio_short_needle_impl(s1, s2):
 
     if len(s1) > len(s2):
         return partial_ratio_short_needle_impl(s2, s1)
-    parts = [
-        s2[max(0, i) : min(len(s2), i + len(s1))] for i in range(-len(s1), len(s2))
-    ]
+    parts = [s2[max(0, i) : min(len(s2), i + len(s1))] for i in range(-len(s1), len(s2))]
     res = 0
     for part in parts:
         res = max(res, fuzz.ratio(s1, part))
@@ -160,11 +156,11 @@ def partial_ratio_short_needle_impl(s1, s2):
 def partial_ratio_short_needle(s1, s2):
     if len(s1) != len(s2):
         return partial_ratio_short_needle_impl(s1, s2)
-    else:
-        return max(
-            partial_ratio_short_needle_impl(s1, s2),
-            partial_ratio_short_needle_impl(s2, s1),
-        )
+
+    return max(
+        partial_ratio_short_needle_impl(s1, s2),
+        partial_ratio_short_needle_impl(s2, s1),
+    )
 
 
 def cdist_scorer(queries, choices, scorer):
@@ -213,7 +209,7 @@ def test_matching_blocks(s1, s2):
     """
     test correct matching block conversion
     """
-    ops = Levenshtein_cpp.editops(s1, s2)
+    ops = metrics_cpp.levenshtein_editops(s1, s2)
     assert ops.as_matching_blocks() == ops.as_opcodes().as_matching_blocks()
 
 
@@ -223,7 +219,7 @@ def test_levenshtein_editops(s1, s2):
     """
     test Levenshtein.editops with any sizes
     """
-    ops = Levenshtein_cpp.editops(s1, s2)
+    ops = metrics_cpp.levenshtein_editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -233,7 +229,7 @@ def test_levenshtein_editops_block(s1, s2):
     """
     test Levenshtein.editops for long strings
     """
-    ops = Levenshtein_cpp.editops(s1, s2)
+    ops = metrics_cpp.levenshtein_editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -243,7 +239,7 @@ def test_indel_editops(s1, s2):
     """
     test Indel.editops with any sizes
     """
-    ops = Indel_cpp.editops(s1, s2)
+    ops = metrics_cpp.indel_editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -253,7 +249,7 @@ def test_indel_editops_block(s1, s2):
     """
     test Indel.editops for long strings
     """
-    ops = Indel_cpp.editops(s1, s2)
+    ops = metrics_cpp.indel_editops(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -263,7 +259,7 @@ def test_levenshtein_opcodes(s1, s2):
     """
     test Levenshtein.opcodes with any sizes
     """
-    ops = Levenshtein_cpp.opcodes(s1, s2)
+    ops = metrics_cpp.levenshtein_opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -273,7 +269,7 @@ def test_levenshtein_opcodes_block(s1, s2):
     """
     test Levenshtein.opcodes for long strings
     """
-    ops = Levenshtein_cpp.opcodes(s1, s2)
+    ops = metrics_cpp.levenshtein_opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -283,7 +279,7 @@ def test_indel_opcodes(s1, s2):
     """
     test Indel.opcodes with any sizes
     """
-    ops = Indel_cpp.opcodes(s1, s2)
+    ops = metrics_cpp.indel_opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -293,7 +289,7 @@ def test_indel_opcodes_block(s1, s2):
     """
     test Indel.opcodes for long strings
     """
-    ops = Indel_cpp.opcodes(s1, s2)
+    ops = metrics_cpp.indel_opcodes(s1, s2)
     assert ops.apply(s1, s2) == s2
 
 
@@ -312,9 +308,7 @@ def test_token_ratio(s1, s2):
     """
     token_ratio should be max(token_sort_ratio, token_set_ratio)
     """
-    assert fuzz.token_ratio(s1, s2) == max(
-        fuzz.token_sort_ratio(s1, s2), fuzz.token_set_ratio(s1, s2)
-    )
+    assert fuzz.token_ratio(s1, s2) == max(fuzz.token_sort_ratio(s1, s2), fuzz.token_set_ratio(s1, s2))
 
 
 @given(s1=st.text(), s2=st.text())
@@ -404,12 +398,10 @@ def test_multiple_processor_runs(sentence):
     Test that running a preprocessor on a sentence
     a second time does not change the result
     """
-    assert utils.default_process(sentence) == utils.default_process(
-        utils.default_process(sentence)
-    )
+    assert utils.default_process(sentence) == utils.default_process(utils.default_process(sentence))
 
 
-@pytest.mark.parametrize("scorer,processor", list(product(FULL_SCORERS, PROCESSORS)))
+@pytest.mark.parametrize(("scorer", "processor"), list(product(FULL_SCORERS, PROCESSORS)))
 @given(choices=st.lists(st.text(), min_size=1))
 @settings(max_examples=50, deadline=1000)
 def test_only_identical_strings_extracted(scorer, processor, choices):
@@ -423,11 +415,9 @@ def test_only_identical_strings_extracted(scorer, processor, choices):
     :return:
     """
     query = random.choice(choices)
-    assume(processor(query) != "")
+    assume(processor(query))
 
-    matches = process.extract(
-        query, choices, scorer=scorer, processor=processor, score_cutoff=100, limit=None
-    )
+    matches = process.extract(query, choices, scorer=scorer, processor=processor, score_cutoff=100, limit=None)
 
     assert matches != []
 
@@ -441,16 +431,16 @@ def test_cdist(queries, choices):
     """
     Test that cdist returns correct results
     """
-
-    reference_matrix = cdist_distance(queries, choices, scorer=Levenshtein_cpp.distance)
-    matrix1 = process.cdist(queries, choices, scorer=Levenshtein_cpp.distance)
+    pytest.importorskip("numpy")
+    reference_matrix = cdist_distance(queries, choices, scorer=metrics_cpp.levenshtein_distance)
+    matrix1 = process.cdist(queries, choices, scorer=metrics_cpp.levenshtein_distance)
     matrix2 = process.cdist(queries, choices, scorer=Levenshtein_py.distance)
     assert (matrix1 == reference_matrix).all()
     assert (matrix2 == reference_matrix).all()
 
-    reference_matrix = cdist_distance(queries, queries, scorer=Levenshtein_cpp.distance)
-    matrix1 = process.cdist(queries, queries, scorer=Levenshtein_cpp.distance)
-    matrix2 = process.cdist(queries, queries, scorer=Levenshtein_cpp.distance)
+    reference_matrix = cdist_distance(queries, queries, scorer=metrics_cpp.levenshtein_distance)
+    matrix1 = process.cdist(queries, queries, scorer=metrics_cpp.levenshtein_distance)
+    matrix2 = process.cdist(queries, queries, scorer=Levenshtein_py.distance)
     assert (matrix1 == reference_matrix).all()
     assert (matrix2 == reference_matrix).all()
 
@@ -462,13 +452,13 @@ def test_jaro_winkler_word(s1, s2):
 
 
 @given(s1=st.text(min_size=65), s2=st.text(min_size=65))
-@settings(max_examples=50, deadline=1000)
+@settings(max_examples=50, deadline=None)
 def test_jaro_winkler_block(s1, s2):
     assert isclose(jaro_winkler_similarity(s1, s2), JaroWinkler.similarity(s1, s2))
 
 
 @given(s1=st.text(), s2=st.text())
-@settings(max_examples=50, deadline=1000)
+@settings(max_examples=50, deadline=None)
 def test_jaro_winkler_random(s1, s2):
     print(s1, s2)
     assert isclose(jaro_winkler_similarity(s1, s2), JaroWinkler.similarity(s1, s2))
